gchecky.model.shipping_package_t

Package gchecky :: Module model :: Class shipping_package_t |
[hide private]
[frames] | no frames]

# Class shipping_package_t

source code

    object --+
             |
     gxml.Node --+
                 |
                shipping_package_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| delivery_address_category = `String:PATH(delivery-address-categ`...``
| height = `Node:PATH(height):REQ:{ measure_t }`
| length = `Node:PATH(length):REQ:{ measure_t }`
| ship_from = `Node:PATH(ship-from):REQ:{ ship_from_t }`
| width = `Node:PATH(width):REQ:{ measure_t }`
| _fields = ``{``'``delivery_address_category``'``:` String:PATH(delivery-a`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### delivery_address_category Value:
      String:PATH(delivery-address-category):OPT:EMPTY:VALS("RESIDENTIAL","C
      OMMERCIAL")

  ### _fields list of meta-Fields of this class. Value:
      {'delivery_address_category': String:PATH(delivery-address-category):O
      PT:EMPTY:VALS("RESIDENTIAL","COMMERCIAL"),
       'height': Node:PATH(height):REQ:{ measure_t },
       'length': Node:PATH(length):REQ:{ measure_t },
       'ship_from': Node:PATH(ship-from):REQ:{ ship_from_t },
       'width': Node:PATH(width):REQ:{ measure_t }}